
Verbose error messaging
-------

**Description:**

In the development stage of an application programmers add debugging information on order 
to debug certain functionalities. 
However, this stage often displays sensitive technical information. 
If an attacker gains this technical information, he can learn more about the operation 
of the application. The application should always display user-friendly messages only when 
put on a live enviroment.


**Solution:**

The level of debug information needs to be determined according to the environment where 
the code is runned.
	